@@ -52,6 +52,22 @@ class cleancss(ExternalCommandTask):
             yield t, self.lazy_clean(c), m
 
 
+class cssshrink(ExternalCommandTask):
+    """Shrink CSS files using cssshrink."""
+
+    def lazy_shrink(self, c):
+        cmd = ['cssshrink']
+        yield self.run_external(cmd, input=b''.join(c))
+
+    def process(self, inputs):
+        for t, c, m in inputs:
+            if t.suffix != '.css':
+                yield t, c, m
+                continue
+
+            yield t, self.lazy_shrink(c), m
+
+
 class lessc(ExternalCommandTask):
     """
     Compile LESS files to CSS.
